package server

import (
	"strconv"

	"github.com/gofiber/fiber/v2"
	"github.com/google/uuid"

	def "git.pbiernat.dev/egommerce/catalog-service/internal/app/definition"
	"git.pbiernat.dev/egommerce/catalog-service/internal/app/service"
)

func prepareBasket(c *fiber.Ctx) string {
	basketID := c.Cookies(service.BasketIdCookieName)
	if len(basketID) == 0 {
		basketID = uuid.New().String()
		c.Cookie(&fiber.Cookie{Name: service.BasketIdCookieName, Value: basketID})
	}

	return basketID
}

func (s *Server) AddProductToBasketHandler(c *fiber.Ctx) error {
	reqID, _ := s.GetRequestID(c)
	data := new(def.AddProductToBasketRequest)
	if err := c.BodyParser(data); err != nil {
		return err
	}

	productID := strconv.Itoa(data.ProductID)
	// vlaidate, pre check... etc

	basketID := prepareBasket(c)
	catalog := service.NewCatalogService(s.ebCh, s.log)
	if err := catalog.AddProductToBasket(reqID, productID, basketID); err != nil {
		return err
	}

	return c.JSON(&def.ProductAddToBasketResponse{
		BasketID: basketID,
	})
}

func (s *Server) RemoveProductFromBasketHandler(c *fiber.Ctx) error {
	reqID, _ := s.GetRequestID(c)
	data := new(def.RemoveProductFromBasketRequest)
	if err := c.BodyParser(data); err != nil {
		return err
	}

	productID := strconv.Itoa(data.ProductID)
	// vlaidate, pre check... etc

	basketID := prepareBasket(c)
	catalog := service.NewCatalogService(s.ebCh, s.log)
	if err := catalog.RemoveProductFromBasket(reqID, productID, basketID); err != nil {
		return err
	}

	return c.JSON(&def.RemoveProductFromBasketResponse{
		BasketID: basketID,
	})
}
