package service

import (
	"git.pbiernat.dev/egommerce/catalog-service/internal/app/event"
	"git.pbiernat.dev/egommerce/go-api-pkg/fluentd"
	amqp "git.pbiernat.dev/egommerce/go-api-pkg/rabbitmq"
	base "github.com/streadway/amqp"
)

const (
	BasketIdCookieName = "basket_id"
)

type CatalogService struct {
	ebCh *base.Channel
	log  *fluentd.Logger
}

func NewCatalogService(chn *base.Channel, log *fluentd.Logger) *CatalogService {
	return &CatalogService{chn, log}
}

func (s *CatalogService) AddProductToBasket(reqID, productID, basketID string) error {
	s.log.Log("Added product#%s to the basket#%s", productID, basketID)

	msg := &event.ProductAddedToBasketEvent{Event: event.NewEvent(reqID), BasketID: basketID, ProductID: productID}
	amqp.Publish(s.ebCh, "api-events", "catalog.basket.productAddedToBasket", msg)
	amqp.Publish(s.ebCh, "api-events", "catalog.warehouse.productAddedToBasket", msg)

	return nil
}

func (s *CatalogService) RemoveProductFromBasket(reqID, productID, basketID string) error {
	s.log.Log("Removed product#%s from basket#%s", productID, basketID)

	msg := &event.ProductRemovedFromBasketEvent{Event: event.NewEvent(reqID), BasketID: basketID, ProductID: productID}
	amqp.Publish(s.ebCh, "api-events", "catalog.basket.productRemovedFromBasket", msg)
	amqp.Publish(s.ebCh, "api-events", "catalog.warehouse.productRemovedFromBasket", msg)

	return nil
}
